@@ -392,8 +392,11 @@ EOM
       sed -i 's/  nodeSelector: .*/  nodeSelector:/' ${PRODUCTSVAR_FILE}
     fi
 
-    # for nodes are not allowed to be labeled
-    if ! ${ALLOW_CREATE_NODE_LABEL}; then
+    # For nodes are not allowed to be labeled
+    # Only need to ensure using pre-defined storageclass for On-Prem case.
+    # For Cloud cases, we set ALLOW_CREATE_NODE_LABEL to false because we don't need to lable the node,
+    # as the node label already being set in the node pool level.
+    if [[ -z "$CLOUDPLATFORM" ]] && ! ${ALLOW_CREATE_NODE_LABEL} ; then
       if [[ -z ${STORAGECLASS_NAME} ]]; then
         echo "[Error] Ensure to provide valid storageclass_name if the allow_create_node_label parameter is set to false."
         exit 1
@@ -703,54 +706,68 @@ EOM
       #  exit 1
       #fi
       #EXT_WHITE_LIST="$(echo $EXT_WHITE_LIST|sed -e 's/]/,/g')$(echo $outbound_ip|sed -e 's/"//g')/32]"
-
-      # Use Auzre file as CMS StoregeClass, need to create this storageClass in deploy-cms step
-      echo "[INFO] Update CMS PVCs with storageclass [cms-azure-file]."
-      sed -i 's/storageClass: "cms-data"/storageClass: "cms-azure-file"/' ${PRODUCTSVAR_FILE}
-
-      # Use azure-file static shares
-      # For Fresh installation, always use static share folders
-      # For upgrade, depents on the migrate_azure_file_storage_class parameter
-      prepare_azure_file_static_sc="false"
-      EXISTING_SC=$(kubectl get sc --request-timeout 60s|awk '{print $1}')
-      if [[ -z $EXISTING_SC ]]; then
-        [Error] Can not fetch StorageClass information from the AKS cluster.
-        exit 1
+      
+      echo "[INFO] Set azureBlobStorage to ${USE_AZURE_BLOB_STORAGE}."
+      yq -i ".azureBlobStorage=\"${USE_AZURE_BLOB_STORAGE}\"" ${PRODUCTSVAR_FILE}
+      
+      if [[ "${USE_AZURE_BLOB_STORAGE}" == "true" ]]; then
+        # Set AZURE_BLOB_STORAGE_ACCOUNT_NAME from aks.env to products-var
+        AZURE_BLOB_STORAGE_ACCOUNT_NAME=$(grep OUTPUT_BLOB_STORAGEACCOUNT_NAME ${CLOUD_ENV} | awk -F '=' '{print $2}')
+        yq -i ".azureBlobStorageAccountName=${AZURE_BLOB_STORAGE_ACCOUNT_NAME}" ${PRODUCTSVAR_FILE}
       fi
 
-      # For upgrade case
-      if [[ -n $(echo "$EXISTING_SC"|grep ^cms-azure-file$) ]]; then
-        if [[ -n $(echo "$EXISTING_SC"|grep ^azure-file-cms-conf$) ]]; then
-          # set to true if the system was fresh installed with static PV SCs.
+      if [[ "${USE_AZURE_FILE_STORAGE}" == "true" ]]; then
+        # Use Auzre file as CMS StoregeClass, need to create this storageClass in deploy-cms step
+        # Only cms-es-snapshot PVC will use this cms-azure-file storageclass to create dynamic PVs
+        echo "[INFO] Update CMS PVCs with storageclass [cms-azure-file]."
+        sed -i 's/storageClass: "cms-data"/storageClass: "cms-azure-file"/' ${PRODUCTSVAR_FILE}
+  
+        # Use azure-file static shares
+        # For Fresh installation, always use static share folders
+        # For upgrade, depents on the migrate_azure_file_storage_class parameter
+        prepare_azure_file_static_sc="false"
+        EXISTING_SC=$(kubectl get sc --request-timeout 60s|awk '{print $1}')
+        if [[ -z $EXISTING_SC ]]; then
+          [Error] Can not fetch StorageClass information from the AKS cluster.
+          exit 1
+        fi
+  
+        # For upgrade case
+        if [[ -n $(echo "$EXISTING_SC"|grep ^cms-azure-file$) ]]; then
+          if [[ -n $(echo "$EXISTING_SC"|grep ^azure-file-cms-conf$) ]]; then
+            # set to true if the system was fresh installed with static PV SCs.
+            prepare_azure_file_static_sc="true"
+          fi
+        # For fresh installation case
+        else
           prepare_azure_file_static_sc="true"
         fi
-      # For fresh installation case
-      else
-        prepare_azure_file_static_sc="true"
-      fi
-
-      if  [[ "$prepare_azure_file_static_sc" == "true" ]]; then
-        echo "[INFO] Update cms-conf PVCs with azure-file static share storageclass [azure-file-cms-conf]."
-        yq -i '.cms_pvc.cmsconf.storageClass="azure-file-cms-conf"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update cms-plugin PVCs with azure-file static share storageclass [azure-file-cms-plugin]."
-        yq -i '.cms_pvc.cmsplugin.storageClass="azure-file-cms-plugin"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update cms-content PVCs with azure-file static share storageclass [azure-file-cms-content]."
-        yq -i '.cms_pvc.cmscontent.storageClass="azure-file-cms-content"' ${PRODUCTSVAR_FILE}
-        #echo "[INFO] Update cms-content-heavy PVCs with azure-file static share storageclass [azure-file-cms-content-heavy]."
-        #yq w -i ${PRODUCTSVAR_FILE} 'cms_pvc.cmscontentheavy.storageClass' "azure-file-cms-content-heavy"
-        echo "[INFO] Update cms-metadata-manager-content PVCs with azure-file static share storageclass [azure-file-cms-metadata-manager-content]."
-        yq -i '.cms_pvc.cmsmetadatamanagercontent.storageClass="azure-file-cms-metadata-manager-content"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update backup-restore PVCs with azure-file static share storageclass [azure-file-backup-restore]."
-        yq -i '.cms_pvc.backuprestore.storageClass="azure-file-backup-restore"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update cmscli-plugin PVCs with azure-file static share storageclass [azure-file-cmscli-plugin]."
-        yq -i '.cms_pvc.cmscliplugin.storageClass="azure-file-cmscli-plugin"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update cms-sync-utils PVCs with azure-file static share storageclass [azure-file-cms-sync-utils]."
-        yq -i '.cms_pvc.cmssyncutils.storageClass="azure-file-cms-sync-utils"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update cms-service-client PVCs with azure-file static share storageclass [azure-file-cms-service-client]."
-        yq -i '.cms_pvc.cmsserviceclient.storageClass="azure-file-cms-service-client"' ${PRODUCTSVAR_FILE}
-        echo "[INFO] Update cms-workflow-runtime PVCs with azure-file static share storageclass [azure-file-cms-workflow-runtime]."
-        yq -i '.cms_pvc.cmsworkflowruntime.storageClass="azure-file-cms-workflow-runtime"' ${PRODUCTSVAR_FILE}
-      fi
+  
+        if  [[ "$prepare_azure_file_static_sc" == "true" ]]; then
+          echo "[INFO] Update cms-conf PVCs with azure-file static share storageclass [azure-file-cms-conf]."
+          yq -i '.cms_pvc.cmsconf.storageClass="azure-file-cms-conf"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cms-plugin PVCs with azure-file static share storageclass [azure-file-cms-plugin]."
+          yq -i '.cms_pvc.cmsplugin.storageClass="azure-file-cms-plugin"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cms-content PVCs with azure-file static share storageclass [azure-file-cms-content]."
+          yq -i '.cms_pvc.cmscontent.storageClass="azure-file-cms-content"' ${PRODUCTSVAR_FILE}
+          #echo "[INFO] Update cms-content-heavy PVCs with azure-file static share storageclass [azure-file-cms-content-heavy]."
+          #yq w -i ${PRODUCTSVAR_FILE} 'cms_pvc.cmscontentheavy.storageClass' "azure-file-cms-content-heavy"
+          echo "[INFO] Update cms-metadata-manager-content PVCs with azure-file static share storageclass [azure-file-cms-metadata-manager-content]."
+          yq -i '.cms_pvc.cmsmetadatamanagercontent.storageClass="azure-file-cms-metadata-manager-content"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update backup-restore PVCs with azure-file static share storageclass [azure-file-backup-restore]."
+          yq -i '.cms_pvc.backuprestore.storageClass="azure-file-backup-restore"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cmscli-plugin PVCs with azure-file static share storageclass [azure-file-cmscli-plugin]."
+          yq -i '.cms_pvc.cmscliplugin.storageClass="azure-file-cmscli-plugin"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cms-sync-utils PVCs with azure-file static share storageclass [azure-file-cms-sync-utils]."
+          yq -i '.cms_pvc.cmssyncutils.storageClass="azure-file-cms-sync-utils"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cms-service-client PVCs with azure-file static share storageclass [azure-file-cms-service-client]."
+          yq -i '.cms_pvc.cmsserviceclient.storageClass="azure-file-cms-service-client"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cms-workflow-runtime PVCs with azure-file static share storageclass [azure-file-cms-workflow-runtime]."
+          yq -i '.cms_pvc.cmsworkflowruntime.storageClass="azure-file-cms-workflow-runtime"' ${PRODUCTSVAR_FILE}
+          echo "[INFO] Update cms-watchfolder-runtime PVCs with azure-file static share storageclass [azure-file-cms-watchfolder-runtime]."
+          yq -i '.cms_pvc.cmswatchfolderruntime.storageClass="azure-file-cms-watchfolder-runtime"' ${PRODUCTSVAR_FILE}
+        fi
+      fi # End handling azure-file storageclass
 
       echo "[INFO] Update ES data PVC with storageclass [cms-disk]."
       yq -i '.cms_esLogging.persistentVolume.data.storageClass="cms-disk"' ${PRODUCTSVAR_FILE}
